summaryrefslogtreecommitdiffstats
path: root/Http/EntryPoint/AuthenticationEntryPointInterface.php
diff options
context:
space:
mode:
authorBernhard Schussek <bernhard.schussek@symfony-project.com>2011-03-07 15:42:52 +0100
committerBernhard Schussek <bernhard.schussek@symfony-project.com>2011-03-07 19:16:05 +0100
commit4a5d6729bc8c7f4adc89c153606617390bb24ca4 (patch)
treee31633b8ef04acfc224c6649d4656e380b6f6b25 /Http/EntryPoint/AuthenticationEntryPointInterface.php
parentdb1564445584b2bf354558534efa6532e8cb3959 (diff)
downloadsymfony-security-4a5d6729bc8c7f4adc89c153606617390bb24ca4.zip
symfony-security-4a5d6729bc8c7f4adc89c153606617390bb24ca4.tar.gz
symfony-security-4a5d6729bc8c7f4adc89c153606617390bb24ca4.tar.bz2
Renamed EventArgs classes and adapted remaining code to EventManager
The only missing part is ContainerAwareEventManager::addEventSubscriberService(), because I'm not sure how to find out the class name of a service in the DIC. Also, inline documentation of this code needs to be finished once it is accepted.
Diffstat (limited to 'Http/EntryPoint/AuthenticationEntryPointInterface.php')
-rw-r--r--Http/EntryPoint/AuthenticationEntryPointInterface.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/Http/EntryPoint/AuthenticationEntryPointInterface.php b/Http/EntryPoint/AuthenticationEntryPointInterface.php
index 8f49971..7d75cbc 100644
--- a/Http/EntryPoint/AuthenticationEntryPointInterface.php
+++ b/Http/EntryPoint/AuthenticationEntryPointInterface.php
@@ -11,7 +11,7 @@
namespace Symfony\Component\Security\Http\EntryPoint;
-use Symfony\Component\HttpKernel\Event\RequestEventArgs;
+use Symfony\Component\HttpKernel\Event\GetResponseEventArgs;
use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\HttpFoundation\Request;
@@ -26,9 +26,9 @@ interface AuthenticationEntryPointInterface
/**
* Starts the authentication scheme.
*
* @param RequestEventArgs $eventArgs The "onCoreSecurity" event
* @param object $request The request that resulted in an AuthenticationException
* @param AuthenticationException $authException The exception that started the authentication process
*/
- function start(RequestEventArgs $eventArgs, Request $request, AuthenticationException $authException = null);
+ function start(GetResponseEventArgs $eventArgs, Request $request, AuthenticationException $authException = null);
}
@@ -26,9 +26,9 @@ interface AuthenticationEntryPointInterface
* Starts the authentication scheme.
*
- * @param RequestEventArgs $eventArgs The "onCoreSecurity" event
+ * @param GetResponseEventArgs $eventArgs The "onCoreSecurity" event
* @param object $request The request that resulted in an AuthenticationException
* @param AuthenticationException $authException The exception that started the authentication process